@@ -37,15 +37,16 @@ public:
 Q_SIGNALS:
     void defaultSinkChanged(Sink *sink);
     void defaultSourceChanged(Source *source);
+    void updated();
 
 private:
     void updateDefaultDevices();
 
     QString m_defaultSinkName;
     QString m_defaultSourceName;
-    Sink *m_defaultSink;
-    Source *m_defaultSource;
-    bool m_isPipeWire;
+    Sink *m_defaultSink = nullptr;
+    Source *m_defaultSource = nullptr;
+    bool m_isPipeWire = false;
 };
 
 } // QPulseAudio
