@@ -19,19 +19,11 @@ public:
 
     void update(const pa_sink_input_info *info);
 
-    void setSinkIndex(quint32 sinkIndex);
-
     void setVolume(qint64 volume) override;
     void setMuted(bool muted) override;
     void setChannelVolume(int channel, qint64 volume) override;
-    void setChannelVolumes(const QVector<qint64> &channelVolumes) override;
+    void setChannelVolumes(const QList<qint64> &channelVolumes) override;
     void setDeviceIndex(quint32 deviceIndex) override;
-
-    quint32 sourceIndex() const override;
-    quint32 streamIndex() const override;
-
-private:
-    quint32 m_sinkIndex = -1;
 };
 
 } // QPulseAudio
