@@ -44,7 +44,7 @@ void SourceOutput::setChannelVolume(int channel, qint64 volume)
     context()->setGenericVolume(index(), channel, volume, cvolume(), &pa_context_set_source_output_volume);
 }
 
-void SourceOutput::setChannelVolumes(const QVector<qint64> &channelVolumes)
+void SourceOutput::setChannelVolumes(const QList<qint64> &channelVolumes)
 {
     context()->setGenericVolumes(index(), channelVolumes, cvolume(), &pa_context_set_source_output_volume);
 }
